@@ -1,26 +1,14 @@
 /* This file is part of Webarchiver
- *
- *  Copyright (C) 2020 Jonathan Marten <jjm@keelhaul.me.uk>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; see the file COPYING.  If not, see
- *  <http://www.gnu.org/licenses/>.
- **/
 
-#include <qapplication.h>
-#include <qcommandlineparser.h>
-#include <qurl.h>
-#include <qicon.h>
+    SPDX-FileCopyrightText: 2020 Jonathan Marten <jjm@keelhaul.me.uk>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#include <QApplication>
+#include <QCommandLineParser>
+#include <QUrl>
+#include <QIcon>
 
 #include <kaboutdata.h>
 #include <klocalizedstring.h>
